<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Réglages de la luminosité</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="24"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paramètres de rétroéclairage et de luminosité:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Utilisez les flèches pour changer les paramètres.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="41"/>
        <source>Require confirmation after settings change</source>
        <translation>Demander confirmation après modification des réglages</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="88"/>
        <source>Brightness settings changed</source>
        <translation>Paramètres de luminosité modifiés</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="89"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Confirmation requise. Les réglages sont-ils corrects ?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Sortie:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="67"/>
        <source>Right click to reset</source>
        <translation>Clic droit pour réinitialiser</translation>
    </message>
</context>
</TS>
